Documentation
¶
Index ¶
- Variables
- type AssignOnlyPatch
- type AssignOnlyPatchBuilder
- type BinaryPatch
- func (p *BinaryPatch) GetAppend() standard3.ByteBuffer
- func (p *BinaryPatch) GetAssign() standard3.ByteBuffer
- func (p *BinaryPatch) GetClear() bool
- func (p *BinaryPatch) GetPrepend() standard3.ByteBuffer
- func (p *BinaryPatch) IsSetAssign() bool
- func (p *BinaryPatch) Read(iprot thrift.Protocol) error
- func (p *BinaryPatch) ReadField1(iprot thrift.Protocol) error
- func (p *BinaryPatch) ReadField2(iprot thrift.Protocol) error
- func (p *BinaryPatch) ReadField8(iprot thrift.Protocol) error
- func (p *BinaryPatch) ReadField9(iprot thrift.Protocol) error
- func (b *BinaryPatch) SetAppend(append standard3.ByteBuffer) *BinaryPatch
- func (b *BinaryPatch) SetAssign(assign standard3.ByteBuffer) *BinaryPatch
- func (b *BinaryPatch) SetClear(clear bool) *BinaryPatch
- func (b *BinaryPatch) SetPrepend(prepend standard3.ByteBuffer) *BinaryPatch
- func (p *BinaryPatch) String() string
- func (p *BinaryPatch) Write(oprot thrift.Protocol) error
- type BinaryPatchBuilder
- func (b *BinaryPatchBuilder) Append(append standard3.ByteBuffer) *BinaryPatchBuilder
- func (b *BinaryPatchBuilder) Assign(assign standard3.ByteBuffer) *BinaryPatchBuilder
- func (b *BinaryPatchBuilder) Clear(clear bool) *BinaryPatchBuilder
- func (p BinaryPatchBuilder) Emit() *BinaryPatch
- func (b *BinaryPatchBuilder) Prepend(prepend standard3.ByteBuffer) *BinaryPatchBuilder
- type BoolPatch
- func (p *BoolPatch) GetAssign() bool
- func (p *BoolPatch) GetClear() bool
- func (p *BoolPatch) GetInvert() bool
- func (p *BoolPatch) IsSetAssign() bool
- func (p *BoolPatch) Read(iprot thrift.Protocol) error
- func (p *BoolPatch) ReadField1(iprot thrift.Protocol) error
- func (p *BoolPatch) ReadField2(iprot thrift.Protocol) error
- func (p *BoolPatch) ReadField9(iprot thrift.Protocol) error
- func (b *BoolPatch) SetAssign(assign *bool) *BoolPatch
- func (b *BoolPatch) SetClear(clear bool) *BoolPatch
- func (b *BoolPatch) SetInvert(invert bool) *BoolPatch
- func (p *BoolPatch) String() string
- func (p *BoolPatch) Write(oprot thrift.Protocol) error
- type BoolPatchBuilder
- type BytePatch
- func (p *BytePatch) GetAdd() int8
- func (p *BytePatch) GetAssign() int8
- func (p *BytePatch) GetClear() bool
- func (p *BytePatch) IsSetAssign() bool
- func (p *BytePatch) Read(iprot thrift.Protocol) error
- func (p *BytePatch) ReadField1(iprot thrift.Protocol) error
- func (p *BytePatch) ReadField2(iprot thrift.Protocol) error
- func (p *BytePatch) ReadField8(iprot thrift.Protocol) error
- func (b *BytePatch) SetAdd(add int8) *BytePatch
- func (b *BytePatch) SetAssign(assign *int8) *BytePatch
- func (b *BytePatch) SetClear(clear bool) *BytePatch
- func (p *BytePatch) String() string
- func (p *BytePatch) Write(oprot thrift.Protocol) error
- type BytePatchBuilder
- type DoublePatch
- func (p *DoublePatch) GetAdd() float64
- func (p *DoublePatch) GetAssign() float64
- func (p *DoublePatch) GetClear() bool
- func (p *DoublePatch) IsSetAssign() bool
- func (p *DoublePatch) Read(iprot thrift.Protocol) error
- func (p *DoublePatch) ReadField1(iprot thrift.Protocol) error
- func (p *DoublePatch) ReadField2(iprot thrift.Protocol) error
- func (p *DoublePatch) ReadField8(iprot thrift.Protocol) error
- func (d *DoublePatch) SetAdd(add float64) *DoublePatch
- func (d *DoublePatch) SetAssign(assign *float64) *DoublePatch
- func (d *DoublePatch) SetClear(clear bool) *DoublePatch
- func (p *DoublePatch) String() string
- func (p *DoublePatch) Write(oprot thrift.Protocol) error
- type DoublePatchBuilder
- type FloatPatch
- func (p *FloatPatch) GetAdd() float32
- func (p *FloatPatch) GetAssign() float32
- func (p *FloatPatch) GetClear() bool
- func (p *FloatPatch) IsSetAssign() bool
- func (p *FloatPatch) Read(iprot thrift.Protocol) error
- func (p *FloatPatch) ReadField1(iprot thrift.Protocol) error
- func (p *FloatPatch) ReadField2(iprot thrift.Protocol) error
- func (p *FloatPatch) ReadField8(iprot thrift.Protocol) error
- func (f *FloatPatch) SetAdd(add float32) *FloatPatch
- func (f *FloatPatch) SetAssign(assign *float32) *FloatPatch
- func (f *FloatPatch) SetClear(clear bool) *FloatPatch
- func (p *FloatPatch) String() string
- func (p *FloatPatch) Write(oprot thrift.Protocol) error
- type FloatPatchBuilder
- type GeneratePatch
- type GeneratePatchBuilder
- type I16Patch
- func (p *I16Patch) GetAdd() int16
- func (p *I16Patch) GetAssign() int16
- func (p *I16Patch) GetClear() bool
- func (p *I16Patch) IsSetAssign() bool
- func (p *I16Patch) Read(iprot thrift.Protocol) error
- func (p *I16Patch) ReadField1(iprot thrift.Protocol) error
- func (p *I16Patch) ReadField2(iprot thrift.Protocol) error
- func (p *I16Patch) ReadField8(iprot thrift.Protocol) error
- func (i *I16Patch) SetAdd(add int16) *I16Patch
- func (i *I16Patch) SetAssign(assign *int16) *I16Patch
- func (i *I16Patch) SetClear(clear bool) *I16Patch
- func (p *I16Patch) String() string
- func (p *I16Patch) Write(oprot thrift.Protocol) error
- type I16PatchBuilder
- type I32Patch
- func (p *I32Patch) GetAdd() int32
- func (p *I32Patch) GetAssign() int32
- func (p *I32Patch) GetClear() bool
- func (p *I32Patch) IsSetAssign() bool
- func (p *I32Patch) Read(iprot thrift.Protocol) error
- func (p *I32Patch) ReadField1(iprot thrift.Protocol) error
- func (p *I32Patch) ReadField2(iprot thrift.Protocol) error
- func (p *I32Patch) ReadField8(iprot thrift.Protocol) error
- func (i *I32Patch) SetAdd(add int32) *I32Patch
- func (i *I32Patch) SetAssign(assign *int32) *I32Patch
- func (i *I32Patch) SetClear(clear bool) *I32Patch
- func (p *I32Patch) String() string
- func (p *I32Patch) Write(oprot thrift.Protocol) error
- type I32PatchBuilder
- type I64Patch
- func (p *I64Patch) GetAdd() int64
- func (p *I64Patch) GetAssign() int64
- func (p *I64Patch) GetClear() bool
- func (p *I64Patch) IsSetAssign() bool
- func (p *I64Patch) Read(iprot thrift.Protocol) error
- func (p *I64Patch) ReadField1(iprot thrift.Protocol) error
- func (p *I64Patch) ReadField2(iprot thrift.Protocol) error
- func (p *I64Patch) ReadField8(iprot thrift.Protocol) error
- func (i *I64Patch) SetAdd(add int64) *I64Patch
- func (i *I64Patch) SetAssign(assign *int64) *I64Patch
- func (i *I64Patch) SetClear(clear bool) *I64Patch
- func (p *I64Patch) String() string
- func (p *I64Patch) Write(oprot thrift.Protocol) error
- type I64PatchBuilder
- type PatchOp
- type StringPatch
- func (p *StringPatch) GetAppend() string
- func (p *StringPatch) GetAssign() string
- func (p *StringPatch) GetClear() bool
- func (p *StringPatch) GetPrepend() string
- func (p *StringPatch) IsSetAssign() bool
- func (p *StringPatch) Read(iprot thrift.Protocol) error
- func (p *StringPatch) ReadField1(iprot thrift.Protocol) error
- func (p *StringPatch) ReadField2(iprot thrift.Protocol) error
- func (p *StringPatch) ReadField8(iprot thrift.Protocol) error
- func (p *StringPatch) ReadField9(iprot thrift.Protocol) error
- func (s *StringPatch) SetAppend(append string) *StringPatch
- func (s *StringPatch) SetAssign(assign *string) *StringPatch
- func (s *StringPatch) SetClear(clear bool) *StringPatch
- func (s *StringPatch) SetPrepend(prepend string) *StringPatch
- func (p *StringPatch) String() string
- func (p *StringPatch) Write(oprot thrift.Protocol) error
- type StringPatchBuilder
- func (s *StringPatchBuilder) Append(append string) *StringPatchBuilder
- func (s *StringPatchBuilder) Assign(assign *string) *StringPatchBuilder
- func (s *StringPatchBuilder) Clear(clear bool) *StringPatchBuilder
- func (p StringPatchBuilder) Emit() *StringPatch
- func (s *StringPatchBuilder) Prepend(prepend string) *StringPatchBuilder
Constants ¶
This section is empty.
Variables ¶
var BinaryPatch_Assign_DEFAULT standard3.ByteBuffer
var BoolPatch_Assign_DEFAULT bool
var BytePatch_Assign_DEFAULT int8
var DoublePatch_Assign_DEFAULT float64
var FloatPatch_Assign_DEFAULT float32
var GoUnusedProtection__ int
var I16Patch_Assign_DEFAULT int16
var I32Patch_Assign_DEFAULT int32
var I64Patch_Assign_DEFAULT int64
var PatchOpNames = []string{
"Assign",
"Clear",
"PatchPrior",
"EnsureUnion",
"EnsureStruct",
"PatchAfter",
"Remove",
"Add",
"Put",
"Unspecified",
}
var PatchOpToName = map[PatchOp]string{ PatchOp_Assign: "Assign", PatchOp_Clear: "Clear", PatchOp_PatchPrior: "PatchPrior", PatchOp_EnsureUnion: "EnsureUnion", PatchOp_EnsureStruct: "EnsureStruct", PatchOp_PatchAfter: "PatchAfter", PatchOp_Remove: "Remove", PatchOp_Add: "Add", PatchOp_Put: "Put", PatchOp_Unspecified: "Unspecified", }
var PatchOpToValue = map[string]PatchOp{ "Assign": PatchOp_Assign, "Clear": PatchOp_Clear, "PatchPrior": PatchOp_PatchPrior, "EnsureUnion": PatchOp_EnsureUnion, "EnsureStruct": PatchOp_EnsureStruct, "PatchAfter": PatchOp_PatchAfter, "Remove": PatchOp_Remove, "Add": PatchOp_Add, "Put": PatchOp_Put, "Unspecified": PatchOp_Unspecified, }
var PatchOpValues = []PatchOp{ PatchOp_Assign, PatchOp_Clear, PatchOp_PatchPrior, PatchOp_EnsureUnion, PatchOp_EnsureStruct, PatchOp_PatchAfter, PatchOp_Remove, PatchOp_Add, PatchOp_Put, PatchOp_Unspecified, }
var StringPatch_Assign_DEFAULT string
Functions ¶
This section is empty.
Types ¶
type AssignOnlyPatch ¶
type AssignOnlyPatch struct {
}
func NewAssignOnlyPatch ¶
func NewAssignOnlyPatch() *AssignOnlyPatch
func (*AssignOnlyPatch) String ¶
func (p *AssignOnlyPatch) String() string
type AssignOnlyPatchBuilder ¶
type AssignOnlyPatchBuilder struct {
// contains filtered or unexported fields
}
func NewAssignOnlyPatchBuilder ¶
func NewAssignOnlyPatchBuilder() *AssignOnlyPatchBuilder
func (AssignOnlyPatchBuilder) Emit ¶
func (p AssignOnlyPatchBuilder) Emit() *AssignOnlyPatch
type BinaryPatch ¶
type BinaryPatch struct {
Assign standard3.ByteBuffer `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 7
Prepend standard3.ByteBuffer `thrift:"prepend,8" db:"prepend" json:"prepend"`
Append standard3.ByteBuffer `thrift:"append,9" db:"append" json:"append"`
}
A patch for a binary value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clear a given binary.
- Prepend: Prepend to a given value.
- Append: Append to a given value.
func NewBinaryPatch ¶
func NewBinaryPatch() *BinaryPatch
func (*BinaryPatch) GetAppend ¶
func (p *BinaryPatch) GetAppend() standard3.ByteBuffer
func (*BinaryPatch) GetAssign ¶
func (p *BinaryPatch) GetAssign() standard3.ByteBuffer
func (*BinaryPatch) GetClear ¶
func (p *BinaryPatch) GetClear() bool
func (*BinaryPatch) GetPrepend ¶
func (p *BinaryPatch) GetPrepend() standard3.ByteBuffer
func (*BinaryPatch) IsSetAssign ¶
func (p *BinaryPatch) IsSetAssign() bool
func (*BinaryPatch) ReadField1 ¶
func (p *BinaryPatch) ReadField1(iprot thrift.Protocol) error
func (*BinaryPatch) ReadField2 ¶
func (p *BinaryPatch) ReadField2(iprot thrift.Protocol) error
func (*BinaryPatch) ReadField8 ¶
func (p *BinaryPatch) ReadField8(iprot thrift.Protocol) error
func (*BinaryPatch) ReadField9 ¶
func (p *BinaryPatch) ReadField9(iprot thrift.Protocol) error
func (*BinaryPatch) SetAppend ¶
func (b *BinaryPatch) SetAppend(append standard3.ByteBuffer) *BinaryPatch
func (*BinaryPatch) SetAssign ¶
func (b *BinaryPatch) SetAssign(assign standard3.ByteBuffer) *BinaryPatch
func (*BinaryPatch) SetClear ¶
func (b *BinaryPatch) SetClear(clear bool) *BinaryPatch
func (*BinaryPatch) SetPrepend ¶
func (b *BinaryPatch) SetPrepend(prepend standard3.ByteBuffer) *BinaryPatch
func (*BinaryPatch) String ¶
func (p *BinaryPatch) String() string
type BinaryPatchBuilder ¶
type BinaryPatchBuilder struct {
// contains filtered or unexported fields
}
func NewBinaryPatchBuilder ¶
func NewBinaryPatchBuilder() *BinaryPatchBuilder
func (*BinaryPatchBuilder) Append ¶
func (b *BinaryPatchBuilder) Append(append standard3.ByteBuffer) *BinaryPatchBuilder
func (*BinaryPatchBuilder) Assign ¶
func (b *BinaryPatchBuilder) Assign(assign standard3.ByteBuffer) *BinaryPatchBuilder
func (*BinaryPatchBuilder) Clear ¶
func (b *BinaryPatchBuilder) Clear(clear bool) *BinaryPatchBuilder
func (BinaryPatchBuilder) Emit ¶
func (p BinaryPatchBuilder) Emit() *BinaryPatch
func (*BinaryPatchBuilder) Prepend ¶
func (b *BinaryPatchBuilder) Prepend(prepend standard3.ByteBuffer) *BinaryPatchBuilder
type BoolPatch ¶
type BoolPatch struct {
Assign *bool `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 8
Invert bool `thrift:"invert,9" db:"invert" json:"invert"`
}
A patch for a boolean value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clear any set value.
- Invert: If the bool value should be inverted.
func NewBoolPatch ¶
func NewBoolPatch() *BoolPatch
func (*BoolPatch) IsSetAssign ¶
type BoolPatchBuilder ¶
type BoolPatchBuilder struct {
// contains filtered or unexported fields
}
func NewBoolPatchBuilder ¶
func NewBoolPatchBuilder() *BoolPatchBuilder
func (*BoolPatchBuilder) Assign ¶
func (b *BoolPatchBuilder) Assign(assign *bool) *BoolPatchBuilder
func (*BoolPatchBuilder) Clear ¶
func (b *BoolPatchBuilder) Clear(clear bool) *BoolPatchBuilder
func (BoolPatchBuilder) Emit ¶
func (p BoolPatchBuilder) Emit() *BoolPatch
func (*BoolPatchBuilder) Invert ¶
func (b *BoolPatchBuilder) Invert(invert bool) *BoolPatchBuilder
type BytePatch ¶
type BytePatch struct {
Assign *int8 `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 7
Add int8 `thrift:"add,8" db:"add" json:"add"`
}
A patch for an 8-bit integer value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clear any set value.
- Add: Add to a given value.
func NewBytePatch ¶
func NewBytePatch() *BytePatch
func (*BytePatch) IsSetAssign ¶
type BytePatchBuilder ¶
type BytePatchBuilder struct {
// contains filtered or unexported fields
}
func NewBytePatchBuilder ¶
func NewBytePatchBuilder() *BytePatchBuilder
func (*BytePatchBuilder) Add ¶
func (b *BytePatchBuilder) Add(add int8) *BytePatchBuilder
func (*BytePatchBuilder) Assign ¶
func (b *BytePatchBuilder) Assign(assign *int8) *BytePatchBuilder
func (*BytePatchBuilder) Clear ¶
func (b *BytePatchBuilder) Clear(clear bool) *BytePatchBuilder
func (BytePatchBuilder) Emit ¶
func (p BytePatchBuilder) Emit() *BytePatch
type DoublePatch ¶
type DoublePatch struct {
Assign *float64 `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 7
Add float64 `thrift:"add,8" db:"add" json:"add"`
}
A patch for an 64-bit floating point value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clear any set value.
- Add: Add to a given value.
func NewDoublePatch ¶
func NewDoublePatch() *DoublePatch
func (*DoublePatch) GetAdd ¶
func (p *DoublePatch) GetAdd() float64
func (*DoublePatch) GetAssign ¶
func (p *DoublePatch) GetAssign() float64
func (*DoublePatch) GetClear ¶
func (p *DoublePatch) GetClear() bool
func (*DoublePatch) IsSetAssign ¶
func (p *DoublePatch) IsSetAssign() bool
func (*DoublePatch) ReadField1 ¶
func (p *DoublePatch) ReadField1(iprot thrift.Protocol) error
func (*DoublePatch) ReadField2 ¶
func (p *DoublePatch) ReadField2(iprot thrift.Protocol) error
func (*DoublePatch) ReadField8 ¶
func (p *DoublePatch) ReadField8(iprot thrift.Protocol) error
func (*DoublePatch) SetAdd ¶
func (d *DoublePatch) SetAdd(add float64) *DoublePatch
func (*DoublePatch) SetAssign ¶
func (d *DoublePatch) SetAssign(assign *float64) *DoublePatch
func (*DoublePatch) SetClear ¶
func (d *DoublePatch) SetClear(clear bool) *DoublePatch
func (*DoublePatch) String ¶
func (p *DoublePatch) String() string
type DoublePatchBuilder ¶
type DoublePatchBuilder struct {
// contains filtered or unexported fields
}
func NewDoublePatchBuilder ¶
func NewDoublePatchBuilder() *DoublePatchBuilder
func (*DoublePatchBuilder) Add ¶
func (d *DoublePatchBuilder) Add(add float64) *DoublePatchBuilder
func (*DoublePatchBuilder) Assign ¶
func (d *DoublePatchBuilder) Assign(assign *float64) *DoublePatchBuilder
func (*DoublePatchBuilder) Clear ¶
func (d *DoublePatchBuilder) Clear(clear bool) *DoublePatchBuilder
func (DoublePatchBuilder) Emit ¶
func (p DoublePatchBuilder) Emit() *DoublePatch
type FloatPatch ¶
type FloatPatch struct {
Assign *float32 `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 7
Add float32 `thrift:"add,8" db:"add" json:"add"`
}
A patch for a 32-bit floating point value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clear any set value.
- Add: Add to a given value.
func NewFloatPatch ¶
func NewFloatPatch() *FloatPatch
func (*FloatPatch) GetAdd ¶
func (p *FloatPatch) GetAdd() float32
func (*FloatPatch) GetAssign ¶
func (p *FloatPatch) GetAssign() float32
func (*FloatPatch) GetClear ¶
func (p *FloatPatch) GetClear() bool
func (*FloatPatch) IsSetAssign ¶
func (p *FloatPatch) IsSetAssign() bool
func (*FloatPatch) ReadField1 ¶
func (p *FloatPatch) ReadField1(iprot thrift.Protocol) error
func (*FloatPatch) ReadField2 ¶
func (p *FloatPatch) ReadField2(iprot thrift.Protocol) error
func (*FloatPatch) ReadField8 ¶
func (p *FloatPatch) ReadField8(iprot thrift.Protocol) error
func (*FloatPatch) SetAdd ¶
func (f *FloatPatch) SetAdd(add float32) *FloatPatch
func (*FloatPatch) SetAssign ¶
func (f *FloatPatch) SetAssign(assign *float32) *FloatPatch
func (*FloatPatch) SetClear ¶
func (f *FloatPatch) SetClear(clear bool) *FloatPatch
func (*FloatPatch) String ¶
func (p *FloatPatch) String() string
type FloatPatchBuilder ¶
type FloatPatchBuilder struct {
// contains filtered or unexported fields
}
func NewFloatPatchBuilder ¶
func NewFloatPatchBuilder() *FloatPatchBuilder
func (*FloatPatchBuilder) Add ¶
func (f *FloatPatchBuilder) Add(add float32) *FloatPatchBuilder
func (*FloatPatchBuilder) Assign ¶
func (f *FloatPatchBuilder) Assign(assign *float32) *FloatPatchBuilder
func (*FloatPatchBuilder) Clear ¶
func (f *FloatPatchBuilder) Clear(clear bool) *FloatPatchBuilder
func (FloatPatchBuilder) Emit ¶
func (p FloatPatchBuilder) Emit() *FloatPatch
type GeneratePatch ¶
type GeneratePatch struct {
}
An annotation that indicates a patch representation should be generated for the associated definition.
func NewGeneratePatch ¶
func NewGeneratePatch() *GeneratePatch
func (*GeneratePatch) String ¶
func (p *GeneratePatch) String() string
type GeneratePatchBuilder ¶
type GeneratePatchBuilder struct {
// contains filtered or unexported fields
}
func NewGeneratePatchBuilder ¶
func NewGeneratePatchBuilder() *GeneratePatchBuilder
func (GeneratePatchBuilder) Emit ¶
func (p GeneratePatchBuilder) Emit() *GeneratePatch
type I16Patch ¶
type I16Patch struct {
Assign *int16 `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 7
Add int16 `thrift:"add,8" db:"add" json:"add"`
}
A patch for a 16-bit integer value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clear any set value.
- Add: Add to a given value.
func NewI16Patch ¶
func NewI16Patch() *I16Patch
func (*I16Patch) IsSetAssign ¶
type I16PatchBuilder ¶
type I16PatchBuilder struct {
// contains filtered or unexported fields
}
func NewI16PatchBuilder ¶
func NewI16PatchBuilder() *I16PatchBuilder
func (*I16PatchBuilder) Add ¶
func (i *I16PatchBuilder) Add(add int16) *I16PatchBuilder
func (*I16PatchBuilder) Assign ¶
func (i *I16PatchBuilder) Assign(assign *int16) *I16PatchBuilder
func (*I16PatchBuilder) Clear ¶
func (i *I16PatchBuilder) Clear(clear bool) *I16PatchBuilder
func (I16PatchBuilder) Emit ¶
func (p I16PatchBuilder) Emit() *I16Patch
type I32Patch ¶
type I32Patch struct {
Assign *int32 `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 7
Add int32 `thrift:"add,8" db:"add" json:"add"`
}
A patch for a 32-bit integer value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clears any set value.
- Add: Add to a given value.
func NewI32Patch ¶
func NewI32Patch() *I32Patch
func (*I32Patch) IsSetAssign ¶
type I32PatchBuilder ¶
type I32PatchBuilder struct {
// contains filtered or unexported fields
}
func NewI32PatchBuilder ¶
func NewI32PatchBuilder() *I32PatchBuilder
func (*I32PatchBuilder) Add ¶
func (i *I32PatchBuilder) Add(add int32) *I32PatchBuilder
func (*I32PatchBuilder) Assign ¶
func (i *I32PatchBuilder) Assign(assign *int32) *I32PatchBuilder
func (*I32PatchBuilder) Clear ¶
func (i *I32PatchBuilder) Clear(clear bool) *I32PatchBuilder
func (I32PatchBuilder) Emit ¶
func (p I32PatchBuilder) Emit() *I32Patch
type I64Patch ¶
type I64Patch struct {
Assign *int64 `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 7
Add int64 `thrift:"add,8" db:"add" json:"add"`
}
A patch for a 64-bit integer value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clear any set value.
- Add: Add to a given value.
func NewI64Patch ¶
func NewI64Patch() *I64Patch
func (*I64Patch) IsSetAssign ¶
type I64PatchBuilder ¶
type I64PatchBuilder struct {
// contains filtered or unexported fields
}
func NewI64PatchBuilder ¶
func NewI64PatchBuilder() *I64PatchBuilder
func (*I64PatchBuilder) Add ¶
func (i *I64PatchBuilder) Add(add int64) *I64PatchBuilder
func (*I64PatchBuilder) Assign ¶
func (i *I64PatchBuilder) Assign(assign *int64) *I64PatchBuilder
func (*I64PatchBuilder) Clear ¶
func (i *I64PatchBuilder) Clear(clear bool) *I64PatchBuilder
func (I64PatchBuilder) Emit ¶
func (p I64PatchBuilder) Emit() *I64Patch
type PatchOp ¶
type PatchOp int64
The meaning of the patch op field ids, in all properly formulated patch definitions.
Patch field ids are interpreted at runtime, as a dynamic patch protocol, without any additional schema derived from IDL patch definitions.
func PatchOpFromString ¶
func PatchOpPtr ¶
type StringPatch ¶
type StringPatch struct {
Assign *string `thrift:"assign,1,optional" db:"assign" json:"assign,omitempty"`
Clear bool `thrift:"clear,2" db:"clear" json:"clear"`
// unused fields # 3 to 7
Prepend string `thrift:"prepend,8" db:"prepend" json:"prepend"`
Append string `thrift:"append,9" db:"append" json:"append"`
}
A patch for a string value.
Attributes:
- Assign: Assigns to a (set) value.
If set, all other patch operations are ignored.
Note: Only modifies set field values.
- Clear: Clear a given string.
- Prepend: Prepend to a given value.
- Append: Append to a given value.
func NewStringPatch ¶
func NewStringPatch() *StringPatch
func (*StringPatch) GetAppend ¶
func (p *StringPatch) GetAppend() string
func (*StringPatch) GetAssign ¶
func (p *StringPatch) GetAssign() string
func (*StringPatch) GetClear ¶
func (p *StringPatch) GetClear() bool
func (*StringPatch) GetPrepend ¶
func (p *StringPatch) GetPrepend() string
func (*StringPatch) IsSetAssign ¶
func (p *StringPatch) IsSetAssign() bool
func (*StringPatch) ReadField1 ¶
func (p *StringPatch) ReadField1(iprot thrift.Protocol) error
func (*StringPatch) ReadField2 ¶
func (p *StringPatch) ReadField2(iprot thrift.Protocol) error
func (*StringPatch) ReadField8 ¶
func (p *StringPatch) ReadField8(iprot thrift.Protocol) error
func (*StringPatch) ReadField9 ¶
func (p *StringPatch) ReadField9(iprot thrift.Protocol) error
func (*StringPatch) SetAppend ¶
func (s *StringPatch) SetAppend(append string) *StringPatch
func (*StringPatch) SetAssign ¶
func (s *StringPatch) SetAssign(assign *string) *StringPatch
func (*StringPatch) SetClear ¶
func (s *StringPatch) SetClear(clear bool) *StringPatch
func (*StringPatch) SetPrepend ¶
func (s *StringPatch) SetPrepend(prepend string) *StringPatch
func (*StringPatch) String ¶
func (p *StringPatch) String() string
type StringPatchBuilder ¶
type StringPatchBuilder struct {
// contains filtered or unexported fields
}
func NewStringPatchBuilder ¶
func NewStringPatchBuilder() *StringPatchBuilder
func (*StringPatchBuilder) Append ¶
func (s *StringPatchBuilder) Append(append string) *StringPatchBuilder
func (*StringPatchBuilder) Assign ¶
func (s *StringPatchBuilder) Assign(assign *string) *StringPatchBuilder
func (*StringPatchBuilder) Clear ¶
func (s *StringPatchBuilder) Clear(clear bool) *StringPatchBuilder
func (StringPatchBuilder) Emit ¶
func (p StringPatchBuilder) Emit() *StringPatch
func (*StringPatchBuilder) Prepend ¶
func (s *StringPatchBuilder) Prepend(prepend string) *StringPatchBuilder